@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 """CalcFunction to compute the powder spectrum of a set of XANES spectra from ``XspectraCalculation``."""
+# ruff: noqa
+
 import warnings
 
 from aiida.common import ValidationError
@@ -8,7 +10,8 @@ from aiida.orm import XyData
 
 warnings.warn(
     'This module is deprecated and will be removed soon as part of migrating XAS and XPS workflows to a new repository.'
-    '\nThe new repository can be found at: https://github.com/aiidaplugins/aiida-qe-xspec.', FutureWarning
+    '\nThe new repository can be found at: https://github.com/aiidaplugins/aiida-qe-xspec.',
+    FutureWarning,
 )
 
 
