@@ -1,19 +1,24 @@
-# -*- coding: utf-8 -*-
-import fnmatch
-from pathlib import Path
 import re
-from typing import List, Optional, Tuple
+import warnings
+from pathlib import Path
+from typing import Optional
 
+import numpy as np
 from aiida.common.extendeddicts import AttributeDict
 from aiida.engine import ExitCode
-from aiida.orm import BandsData, Dict, KpointsData, ProjectionData, StructureData, XyData
-from aiida.plugins import DataFactory, OrbitalFactory
+from aiida.orm import (
+    BandsData,
+    Dict,
+    KpointsData,
+    ProjectionData,
+    StructureData,
+    XyData,
+)
+from aiida.plugins import OrbitalFactory
 from aiida.tools.data.orbital.orbital import Orbital
-import numpy as np
 from numpy.typing import ArrayLike
 
 from aiida_quantumespresso.parsers.parse_raw.base import (
-    convert_qe_time_to_sec,
     convert_qe_to_aiida_structure,
     convert_qe_to_kpoints,
 )
@@ -37,11 +42,6 @@ class ProjwfcParser(BaseParser):
 
         self.out('output_parameters', Dict(dict=parsed_data))
 
-        # Split the stdout into header and k-point blocks - TODO: Lowdin
-        stdout_blocks = stdout.split('Lowdin Charges:')[0].split('k = ')
-        header = stdout_blocks[0]
-        kpoint_blocks = stdout_blocks[1:]
-
         # Check that the temporary retrieved folder is there
         try:
             retrieved_temporary_folder = Path(kwargs['retrieved_temporary_folder'])
@@ -61,31 +61,64 @@ class ProjwfcParser(BaseParser):
         spinorbit = parsed_xml.get('spin_orbit_calculation')
         non_collinear = parsed_xml.get('non_colinear_calculation')
 
-        orbitals = self._parse_orbitals(header, structure, non_collinear, spinorbit)
-        bands, projections = self._parse_bands_and_projections(kpoint_blocks, len(orbitals))
-        energy, dos_node, pdos_array = self._parse_pdos_files(retrieved_temporary_folder, nspin, spinorbit, logs)
+        # There are two possible types of projection:
+        # 1. onto atomic orbitals -> read *pdos_tot* and *pdos_atm* files to extract DOS, PDOS and projections
+        # 2. into boxes -> read *ldos_boxes* file to extract DOS and LDOS
+        projection_orbitals = 'Lowdin Charges' in stdout
+        projection_boxes = 'projwave_boxes' in stdout
 
-        self.out('Dos', dos_node)
+        if projection_orbitals:
+            # Split the stdout into header and k-point blocks - TODO: Lowdin
+            stdout_blocks = stdout.split('Lowdin Charges:')[0].split('k = ')
+            header = stdout_blocks[0]
+            kpoint_blocks = stdout_blocks[1:]
 
-        output_node_dict = self._build_bands_and_projections(
-            kpoints, bands, energy, orbitals, projections, pdos_array, nspin
-        )
-        for linkname, node in output_node_dict.items():
-            self.out(linkname, node)
+            orbitals = self._parse_orbitals(header, structure, non_collinear, spinorbit)
+
+            bands, projections = self._parse_bands_and_projections(kpoint_blocks, len(orbitals))
+            energy, dos_node, pdos_node, pdos_array = self._parse_pdos_files(
+                retrieved_temporary_folder, nspin, spinorbit, logs
+            )
+
+            self.out('Dos', dos_node)
+            self.out('Pdos', pdos_node)
+
+            output_node_dict = self._build_bands_and_projections(
+                kpoints, bands, energy, orbitals, projections, pdos_array, nspin
+            )
+
+            for linkname, node in output_node_dict.items():
+                self.out(linkname, node)
+        elif projection_boxes:
+            energy, dos_node, pdos_node, ldos_node = self._parse_ldos_boxes_file(
+                retrieved_temporary_folder, nspin, logs
+            )
+            self.out('Dos', dos_node)
+            self.out('Pdos', pdos_node)
+            self.out('Ldos', ldos_node)
+        else:
+            msg = (
+                'ProjwfcParser: Could not detect projection type! The calculation may have been interrupted or did not'
+                'complete successfully.'
+            )
+            warnings.warn(msg)
 
         for exit_code in [
             'ERROR_OUTPUT_STDOUT_MISSING',
             'ERROR_OUTPUT_STDOUT_READ',
             'ERROR_OUTPUT_STDOUT_PARSE',
             'ERROR_OUTPUT_STDOUT_INCOMPLETE',
-            'ERROR_READING_PDOSTOT_FILE'
+            'ERROR_READING_PDOSTOT_FILE',
+            'ERROR_READING_LDOSBOXES_FILE',
+            'ERROR_MISSING_PDOSTOT_FILE',
+            'ERROR_MISSING_LDOSBOXES_FILE',
         ]:
             if exit_code in logs.error:
                 return self.exit(self.exit_codes.get(exit_code), logs)
 
         return self.exit(logs=logs)
 
-    def _parse_xml(self, retrieved_temporary_folder: Path) -> Tuple[dict, AttributeDict, Optional[ExitCode]]:
+    def _parse_xml(self, retrieved_temporary_folder: Path) -> tuple[dict, AttributeDict, Optional[ExitCode]]:
         """Parse the XML file.
 
         The XML must be parsed in order to obtain the required information for the other parser methods.
@@ -107,15 +140,20 @@ class ProjwfcParser(BaseParser):
         try:
             with xml_filepath.open('r') as handle:
                 parsed_xml, logs = parse_xml(handle, None)
-            return parsed_xml, logs, None
-        except IOError:
+        except OSError:
             return {}, logs, self.exit(self.exit_codes.ERROR_OUTPUT_XML_READ)
         except XMLParseError:
             return {}, logs, self.exit(self.exit_codes.ERROR_OUTPUT_XML_PARSE)
         except XMLUnsupportedFormatError:
             return {}, logs, self.exit(self.exit_codes.ERROR_OUTPUT_XML_FORMAT)
         except Exception:
-            return {}, logs, self.exit(self.exit_codes.ERROR_UNEXPECTED_PARSER_EXCEPTION)
+            return (
+                {},
+                logs,
+                self.exit(self.exit_codes.ERROR_UNEXPECTED_PARSER_EXCEPTION),
+            )
+
+        return parsed_xml, logs, None
 
     @staticmethod
     def _parse_orbitals(header: str, structure: StructureData, non_collinear: bool, spinorbit: bool) -> list:
@@ -160,14 +198,26 @@ class ProjwfcParser(BaseParser):
             orbital_pattern = re.compile(
                 r'state\s#\s*\d+:\satom\s+(\d+)\s\((\S+)\s*\),\swfc\s+\d+\s\(l=(\d)\sj=\s*(.*)\sm_j=(.*)\)'
             )
-            orbital_keys = ('atomnum', 'kind_name', 'angular_momentum', 'total_angular_momentum', 'magnetic_number')
+            orbital_keys = (
+                'atomnum',
+                'kind_name',
+                'angular_momentum',
+                'total_angular_momentum',
+                'magnetic_number',
+            )
             orbital_types = (int, str, int, float, float)
         elif non_collinear:
             # FORMAT (5x,"state #",i4,": atom ",i3," (",a3,"), wfc ",i2," (l=",i1," m=",i2," s_z=",f4.1,")")
             orbital_pattern = re.compile(
                 r'state\s#\s*\d+:\satom\s+(\d+)\s\((\S+)\s*\),\swfc\s+\d+\s\(l=(\d)\sm=\s?(\d+)\ss_z=(.*)\)'
             )
-            orbital_keys = ('atomnum', 'kind_name', 'angular_momentum', 'magnetic_number', 'spin')
+            orbital_keys = (
+                'atomnum',
+                'kind_name',
+                'angular_momentum',
+                'magnetic_number',
+                'spin',
+            )
             orbital_types = (int, str, int, int, float)
         else:
             # This works for both collinear / no spin
@@ -175,7 +225,12 @@ class ProjwfcParser(BaseParser):
             orbital_pattern = re.compile(
                 r'state\s#\s*\d+:\satom\s+(\d+)\s\((\S+)\s*\),\swfc\s+\d+\s\(l=(\d)\sm=\s?(\d+)\)'
             )
-            orbital_keys = ('atomnum', 'kind_name', 'angular_momentum', 'magnetic_number')
+            orbital_keys = (
+                'atomnum',
+                'kind_name',
+                'angular_momentum',
+                'magnetic_number',
+            )
             orbital_types = (int, str, int, int)
 
         orbital_dicts = []
@@ -212,14 +267,14 @@ class ProjwfcParser(BaseParser):
         elif non_collinear:
             orbital_class = OrbitalFactory('noncollinearhydrogen')
         else:
-            orbital_class = OrbitalFactory('realhydrogen')
+            orbital_class = OrbitalFactory('core.realhydrogen')
         for new_orbital_dict in orbital_dicts:
             orbitals.append(orbital_class(**new_orbital_dict))
 
         return orbitals
 
     @staticmethod
-    def _parse_bands_and_projections(kpoint_blocks: list, num_orbitals: int) -> Tuple[ArrayLike, ArrayLike]:
+    def _parse_bands_and_projections(kpoint_blocks: list, num_orbitals: int) -> tuple[ArrayLike, ArrayLike]:
         """Parse the bands energies and orbital projections from the kpoint blocks in the stdout.
 
         :param kpoint_blocks: list of blocks for each k-point that contain the energies and projections in the stdout.
@@ -230,7 +285,7 @@ class ProjwfcParser(BaseParser):
 
         # Parse the bands energies
         energy_pattern = re.compile(r'====\se\(\s*\d+\)\s=\s*(\S+)\seV\s====')
-        bands = np.array([energy_pattern.findall(block) for block in kpoint_blocks])
+        bands = np.array([energy_pattern.findall(block) for block in kpoint_blocks], dtype=float)
 
         # Parse the projection arrays
         energy_pattern = re.compile(r'\n====.+==== \n')
@@ -239,11 +294,9 @@ class ProjwfcParser(BaseParser):
         projections = []
 
         for block in kpoint_blocks:
-
             kpoint_projections = []
 
             for band_projections in re.split(energy_pattern, block)[1:]:
-
                 proj_array = np.zeros(num_orbitals)
 
                 for [projection_value, orbital_index] in psi_pattern.findall(band_projections):
@@ -257,8 +310,13 @@ class ProjwfcParser(BaseParser):
 
         return bands, projections
 
-    def _parse_pdos_files(self, retrieved_temporary_folder: Path, nspin: int,
-                          spinorbit: bool, logs: AttributeDict) -> Tuple[ArrayLike, XyData, ArrayLike]:
+    def _parse_pdos_files(
+        self,
+        retrieved_temporary_folder: Path,
+        nspin: int,
+        spinorbit: bool,
+        logs: AttributeDict,
+    ) -> tuple[ArrayLike, XyData, XyData, ArrayLike]:
         """Parse the PDOS files and convert them into arrays.
 
         Reads in all of the ``*.pdos*`` files and converts the data into arrays. The PDOS arrays are then concatenated
@@ -273,7 +331,8 @@ class ProjwfcParser(BaseParser):
         :param nspin: nspin value of the parent calculation.
         :param spinorbit: True if the calculation used spin-orbit coupling.
 
-        :return: tuple of three containing the energy grid, the total DOS as a node and the PDOS
+        :return: tuple of four containing the energy grid, the total DOS as a node, the total PDOS as a node and the
+            PDOS array of projections on orbitals
         """
 
         def natural_sort_key(sort_key, _nsre=re.compile('([0-9]+)')):
@@ -295,67 +354,188 @@ class ProjwfcParser(BaseParser):
         try:
             pdostot_filepath = next(retrieved_temporary_folder.glob('*pdos_tot*'))
             with pdostot_filepath.open('r') as pdostot_file:
-                # Columns: Energy(eV), Ldos, Pdos
+                # Columns: Energy(eV), Ldos, Pdos if not kresolved
+                # Columns: ik, Energy(eV), Ldos, Pdos if kresolved
+                labels = pdostot_file.readline().strip()
                 pdostot_array = np.atleast_2d(np.genfromtxt(pdostot_file))
         except (OSError, KeyError):
             logs.error.append('ERROR_READING_PDOSTOT_FILE')
             return np.array([]), XyData(), np.array([])
+        except StopIteration:
+            logs.error.append('ERROR_MISSING_PDOSTOT_FILE')
+            return np.array([]), XyData(), np.array([])
 
-        energy = pdostot_array[:, 0]
+        is_kresolved = re.search(r'ik', labels) is not None
+        index_offset = 1 if is_kresolved else 0
 
-        dos_node = XyData()
+        # Change from 1D arrays to 2D arrays for each column if k-resolved
+        if is_kresolved:
+            unique_iks = np.unique(pdostot_array[:, 0]).astype(int)  # Unique k-points indices (starting from 1)
+            unique_energies = np.unique(pdostot_array[:, 1])  # Unique energy values
+            pdostot_array = pdostot_array.reshape(
+                len(unique_iks), len(unique_energies), -1
+            )  # Reshape to (num_kpoints, num_energies, num_columns)
+
+        energy = pdostot_array[Ellipsis, index_offset]
+
+        dos_node = XyData()  # Total DOS
         dos_node.set_x(energy, 'Energy', 'eV')
 
-        # For spin-polarised calculations the total DOS is split up in spin up and down
+        pdos_node = XyData()  # Total PDOS (on all orbitals)
+        pdos_node.set_x(energy, 'Energy', 'eV')
+
+        # For spin-polarised calculations the total DOS and the total PDOS are split up in spin up and down
         if nspin == 2:
             dos_node.set_y(
-                (pdostot_array[:, 1], pdostot_array[:, 2]),
+                (pdostot_array[Ellipsis, index_offset + 1], pdostot_array[Ellipsis, index_offset + 2]),
                 ('dos_up', 'dos_down'),
-                ('states/eV', 'states/eV')
+                ('states/eV', 'states/eV'),
+            )
+            pdos_node.set_y(
+                (pdostot_array[Ellipsis, index_offset + 3], pdostot_array[Ellipsis, index_offset + 4]),
+                ('pdos_up', 'pdos_down'),
+                ('states/eV', 'states/eV'),
             )
         else:
-            dos_node.set_y(pdostot_array[:, 1], 'Dos', 'states/eV')
+            dos_node.set_y(pdostot_array[Ellipsis, index_offset + 1], 'Dos', 'states/eV')
+            pdos_node.set_y(pdostot_array[Ellipsis, index_offset + 2], 'Pdos', 'states/eV')
 
         # We're only interested in the PDOS, so we skip the first columns corresponding to the energy and LDOS
-        if nspin == 1 or spinorbit:
-            first_pdos_column = 2
-        else:
-            first_pdos_column = 3
+        first_pdos_column = 2 if nspin == 1 or spinorbit else 3
+        first_pdos_column += index_offset  # Add offset when k-resolved
 
         # Read the `pdos_atm` files
         pdos_atm_array_dict = {}
         for path in retrieved_temporary_folder.glob('*pdos_atm*'):
             with path.open('r') as pdosatm_file:
-                pdos_atm_array_dict[path.name] = np.atleast_2d(np.genfromtxt(pdosatm_file))[:, first_pdos_column:]
+                pdos_atm_array = np.atleast_2d(np.genfromtxt(pdosatm_file))
+                if is_kresolved:
+                    # Reshape to (num_kpoints, num_energies, num_columns)
+                    pdos_atm_array = pdos_atm_array.reshape(len(unique_iks), len(unique_energies), -1)
+                pdos_atm_array_dict[path.name] = pdos_atm_array[Ellipsis, first_pdos_column:]
 
         # Keep the pdos in sync with the orbitals by properly sorting the filenames
-        pdos_file_names = [k for k in pdos_atm_array_dict]
+        pdos_file_names = list(pdos_atm_array_dict)
         pdos_file_names.sort(key=natural_sort_key)
 
         # Make sure the order of the PDOS columns matches with the orbitals
         if nspin != 4 or spinorbit:
             # Simply concatenate the PDOS columns as they are ordered by the filenames
-            pdos_array = np.concatenate([pdos_atm_array_dict[name] for name in pdos_file_names], axis=1)
+            pdos_array = np.concatenate([pdos_atm_array_dict[name] for name in pdos_file_names], axis=-1)
             if nspin == 2:
                 # Reorder the columns so the 'up' spin columns are first
-                pdos_array = np.concatenate([pdos_array[:, 0::2], pdos_array[:, 1::2]], axis=1)
+                pdos_array = np.concatenate([pdos_array[Ellipsis, 0::2], pdos_array[Ellipsis, 1::2]], axis=-1)
             if nspin == 4:
                 # Reorder the columns like the order of orbitals for spin-orbit
-                pdos_array = np.concatenate([pdos_array[:, 1::2], pdos_array[:, 0::2]], axis=1)
+                pdos_array = np.concatenate([pdos_array[Ellipsis, 1::2], pdos_array[Ellipsis, 0::2]], axis=-1)
         else:
             # Here all the 'up' orbitals for each l number come first, so the PDOS columns must be sorted accordingly
             pdos_list = []
             for wfc_pdos_array in [pdos_atm_array_dict[name] for name in pdos_file_names]:
                 # Reorder the columns so the 'up' spin columns _for this l number_ come first
-                pdos_list.append(np.concatenate([wfc_pdos_array[:, 0::2], wfc_pdos_array[:, 1::2]], axis=1))
-            pdos_array = np.concatenate(pdos_list, axis=1)
+                pdos_list.append(
+                    np.concatenate([wfc_pdos_array[Ellipsis, 0::2], wfc_pdos_array[Ellipsis, 1::2]], axis=-1)
+                )
+            pdos_array = np.concatenate(pdos_list, axis=-1)
 
-        return energy, dos_node, pdos_array
+        return energy, dos_node, pdos_node, pdos_array
+
+    def _parse_ldos_boxes_file(
+        self, retrieved_temporary_folder: Path, nspin: int, logs: AttributeDict
+    ) -> tuple[ArrayLike, XyData, XyData, XyData]:
+        """Parse the LDOS file and convert it into arrays.
+
+        Reads in the ``*ldos_boxes*`` file and converts the data into arrays. Only works and tested for nspin = 1 or 2.
+
+        :param retrieved_temporary_folder: temporary folder of retrieved files that is deleted after parsing.
+        :param nspin: number of spin components, nspin value of the parent calculation.
+
+        :return: tuple of four containing the energy grid, the total DOS as a node and the LDOS as a node
+        """
+
+        try:
+            ldosboxes_filepath = next(retrieved_temporary_folder.glob('*ldos_boxes*'))
+            with ldosboxes_filepath.open('r') as ldosboxes_file:
+                # Columns: Energy(eV), Dos, Ldos_total, Ldos_box1, Ldos_box2, ... if not kresolved
+                # Columns: ik, Energy(eV), Dos, Ldos_total, Ldos_box1, Ldos_box2, ... if kresolved
+                labels = ldosboxes_file.readline().strip()
+                ldosboxes_array = np.atleast_2d(np.genfromtxt(ldosboxes_file))
+        except (OSError, KeyError):
+            logs.error.append('ERROR_READING_LDOSBOXES_FILE')
+            return np.array([]), XyData(), XyData()
+        except StopIteration:
+            logs.error.append('ERROR_MISSING_LDOSBOXES_FILE')
+            return np.array([]), XyData(), XyData()
+
+        is_kresolved = re.search(r'ik', labels) is not None
+        index_offset = 1 if is_kresolved else 0
+
+        # Change from 1D arrays to 2D arrays for each column if k-resolved
+        if is_kresolved:
+            unique_iks = np.unique(ldosboxes_array[:, 0]).astype(int)  # Unique k-points indices (starting from 1)
+            unique_energies = np.unique(ldosboxes_array[:, 1])  # Unique energy values
+            ldosboxes_array = ldosboxes_array.reshape(
+                len(unique_iks), len(unique_energies), -1
+            )  # Reshape to (num_kpoints, num_energies, num_columns)
+
+        energy = ldosboxes_array[Ellipsis, index_offset]
+
+        dos_node = XyData()  # Total DOS
+        dos_node.set_x(energy, 'Energy', 'eV')
+
+        pdos_node = XyData()  # Total PDOS (on all boxes)
+        pdos_node.set_x(energy, 'Energy', 'eV')
+
+        # For spin-polarized calculations the total DOS and the total PDOS are split up in spin up and down and so are the LDOS for each box
+        if nspin == 2:
+            dos_node.set_y(
+                (ldosboxes_array[Ellipsis, index_offset + 1], ldosboxes_array[Ellipsis, index_offset + 2]),
+                ('dos_up', 'dos_down'),
+                ('states/eV', 'states/eV'),
+            )
+            pdos_node.set_y(
+                (ldosboxes_array[Ellipsis, index_offset + 3], ldosboxes_array[Ellipsis, index_offset + 4]),
+                ('pdos_up', 'pdos_down'),
+                ('states/eV', 'states/eV'),
+            )
+        else:
+            # For unpolarized or non-collinear (with or without SOC) calculations, the total DOS and the total PDOS are not split, and neither are the LDOS
+            dos_node.set_y(ldosboxes_array[Ellipsis, index_offset + 1], 'Dos', 'states/eV')
+            pdos_node.set_y(ldosboxes_array[Ellipsis, index_offset + 2], 'Pdos', 'states/eV')
+
+        ldos_node = XyData()
+        ldos_node.set_x(energy, 'Energy', 'eV')
+
+        num_boxes = (ldosboxes_array.shape[-1] - (index_offset + 1 + nspin * 2)) // nspin  # for nspin = 1 or 2
+
+        if nspin == 2:
+            num_boxes = (ldosboxes_array.shape[-1] - (index_offset + 5)) // 2
+            ldos_node.set_y(
+                [ldosboxes_array[Ellipsis, index_offset + i * 2 + 5] for i in range(num_boxes)]
+                + [ldosboxes_array[Ellipsis, index_offset + i * 2 + 6] for i in range(num_boxes)],
+                [f'ldos_up_box{i + 1}' for i in range(num_boxes)] + [f'ldos_down_box{i + 1}' for i in range(num_boxes)],
+                ['states/eV'] * (num_boxes * 2),
+            )
+        else:
+            num_boxes = ldosboxes_array.shape[-1] - (index_offset + 3)
+            ldos_node.set_y(
+                [ldosboxes_array[Ellipsis, index_offset + i + 3] for i in range(num_boxes)],
+                [f'ldos_box{i + 1}' for i in range(num_boxes)],
+                ['states/eV'] * num_boxes,
+            )
+
+        return energy, dos_node, pdos_node, ldos_node
 
     @classmethod
     def _build_bands_and_projections(
-        cls, kpoints: KpointsData, bands: ArrayLike, energy: ArrayLike, orbitals: List[Orbital], projections: ArrayLike,
-        pdos_array: ArrayLike, nspin: int
+        cls,
+        kpoints: KpointsData,
+        bands: ArrayLike,
+        energy: ArrayLike,
+        orbitals: list[Orbital],
+        projections: ArrayLike,
+        pdos_array: ArrayLike,
+        nspin: int,
     ) -> dict:
         """Build the ``BandsData`` and ``ProjectionData`` output nodes.
 
@@ -372,8 +552,12 @@ class ProjwfcParser(BaseParser):
         num_orbitals = len(orbitals)
 
         bands_data, projection_data = cls._intialize_bands_projection_data(
-            kpoints, bands[:num_kpoints, :], energy, orbitals, projections[:num_kpoints, :, :],
-            pdos_array[:, :num_orbitals]
+            kpoints,
+            bands[:num_kpoints, :],
+            energy,
+            orbitals,
+            projections[:num_kpoints, :, :],
+            pdos_array[Ellipsis, :num_orbitals],
         )
         if nspin == 2:
             # For collinear spin-polarised calculations, each orbital has an 'up' and 'down' projection.
@@ -389,8 +573,12 @@ class ProjwfcParser(BaseParser):
             # The `pdos_arrays` are constructed to match this order, i.e. the first len(orbitals) correspond to 'up'.
             # The 'up' bands and projections have already been initialized above, the 'down' we do now.
             bands_data_down, projection_data_down = cls._intialize_bands_projection_data(
-                kpoints, bands[num_kpoints:, :], energy, orbitals, projections[num_kpoints:, :, :],
-                pdos_array[:, num_orbitals:]
+                kpoints,
+                bands[num_kpoints:, :],
+                energy,
+                orbitals,
+                projections[num_kpoints:, :, :],
+                pdos_array[Ellipsis, num_orbitals:],
             )
             return {
                 'bands_up': bands_data,
@@ -403,9 +591,13 @@ class ProjwfcParser(BaseParser):
 
     @staticmethod
     def _intialize_bands_projection_data(
-        kpoints: KpointsData, bands: ArrayLike, energy: ArrayLike, orbitals: List[Orbital], projections: ArrayLike,
-        pdos_array: ArrayLike
-    ) -> Tuple[BandsData, ProjectionData]:
+        kpoints: KpointsData,
+        bands: ArrayLike,
+        energy: ArrayLike,
+        orbitals: list[Orbital],
+        projections: ArrayLike,
+        pdos_array: ArrayLike,
+    ) -> tuple[BandsData, ProjectionData]:
         """Initialize an instance of ``BandsData`` and corresponding ``ProjectionData``.
 
         :param kpoints: data node that contains the list of k-points.
@@ -428,7 +620,7 @@ class ProjwfcParser(BaseParser):
             orbitals,
             list_of_projections=[projections[:, :, i] for i in range(len(orbitals))],
             list_of_energy=energy_arrays,
-            list_of_pdos=[pdos_array[:, i] for i in range(len(orbitals))],
-            bands_check=False
+            list_of_pdos=[pdos_array[Ellipsis, i] for i in range(len(orbitals))],
+            bands_check=False,
         )
         return bands_data, projection_data
